@@ -17,4 +17,4 @@ def process_input(
     sources = np.atleast_2d(sources)
     destinations = np.atleast_2d(destinations)
 
-    return sources, destinations
+    return sources, destinations  # type: ignore
